@@ -13,11 +13,11 @@ class Database():
         self.user = os.getenv('DB_USER')
         self.password = os.getenv('DB_PASS')
         self.connect = connect(
-            'host': '170-187-194-33.ip.linodeusercontent.com',
-            'user': os.getenv('DB_USER'),
-            'password': os.getenv('DB_PASS'),
-            'port': '3306',
-            'ssl_disabled': True
+            host='170-187-194-33.ip.linodeusercontent.com',
+            user=os.getenv('DB_USER'),
+            password=os.getenv('DB_PASS'),
+            port='3306',
+            ssl_disabled=True
         )
         
         # check if database exists and create it if it doesn't exist
